@@ -18,13 +18,20 @@ using namespace Rcpp;
 // pair of ids and dists
 typedef std::pair< std::vector<int>, std::vector<double> > nn ;
 
+// Note: Region query returns self-matches!
 
+// these function takes an id for the points in the k-d tree
 nn regionQueryDist(int id, ANNpointArray dataPts, ANNpointSet* kdTree,
   double eps2, double approx);
 
 std::vector<int> regionQuery(int id, ANNpointArray dataPts, ANNpointSet* kdTree,
   double eps2, double approx);
 
+// these function takes an query point not in the tree
+nn regionQueryDist_point(ANNpoint queryPt, ANNpointArray dataPts, ANNpointSet* kdTree,
+  double eps2, double approx);
 
+std::vector<int> regionQuery_point(ANNpoint queryPt, ANNpointArray dataPts, ANNpointSet* kdTree,
+  double eps2, double approx);
 
 #endif
